@@ -24,14 +24,19 @@ for i in range(len(WORDS)):
 
 def main():
     """Run a single game of Hacking."""
-    print('Hacking Minigame, by Al Sweigart al@inventwithpython.com')
+    print('''Hacking Minigame, by Al Sweigart al@inventwithpython.com
+Find the password in the computer's memory. You are given clues after
+each guess. For example, if the secret password is MONITOR but the player
+guessed CONTAIN, they are given the hint that 2 out of 7 letters were
+correct, because both MONITOR and CONTAIN have the letter O and N as
+their 2nd and 3rd letter. You get four guesses.''')
+    input('Press Enter to begin...')
 
     gameWords = getWords()
     # The "computer memory" is just cosmetic, but it looks cool:
     computerMemory = getComputerMemoryString(gameWords)
     secretPassword = random.choice(gameWords)
 
-    print('Find the password in the computer\'s memory:')
     print(computerMemory)
     # Start at 4 tries remaining, going down:
     for triesRemaining in range(4, 0, -1):
