@@ -1,10 +1,10 @@
 """Hex Grid, by Al Sweigart al@inventwithpython.com
-
 Displays a simple tessellation of a hexagon grid.
-Tags: tiny, artistic"""
+This and other games are available at https://nostarch.com/XX
+Tags: tiny, beginner, artistic"""
 __version__ = 0
-
 # Set up the constants:
+# (!) Try changing these values to other numbers:
 X_REPEAT = 19  # How many times to tessellate horizontally.
 Y_REPEAT = 12  # How many times to tessellate vertically.
 
